@@ -1,7 +1,7 @@
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
-EventChat = import_string(api_settings.EVENT['chat']['models'])
+from bluedot_rest_framework import import_string
+
+EventChat = import_string('EVENT.chat.models')
 
 
 class EventChatSerializer(CustomSerializer):
