@@ -1,9 +1,9 @@
 
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
-EventChat = import_string(api_settings.EVENT['chat']['models'])
-EventChatSerializer = import_string(api_settings.EVENT['chat']['serializers'])
+
+EventChat = import_string('EVENT.chat.models')
+EventChatSerializer = import_string('EVENT.chat.serializers')
 
 
 class EventChatView(CustomModelViewSet, AllView):
