@@ -2,9 +2,10 @@ from django.db import models
 
 
 class AbstractEventRegister(models.Model):
-    user_id = models.IntegerField()
-    unionid = models.CharField(max_length=100)
-    openid = models.CharField(max_length=100)
+    user_id = models.IntegerField(null=True)
+    unionid = models.CharField(max_length=100, null=True)
+    openid = models.CharField(max_length=100, null=True)
+    wechat_id = models.IntegerField(null=True)
     event_id = models.CharField(max_length=32)
 
     source = models.IntegerField(default=0)
