@@ -1,14 +1,18 @@
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from rest_framework.serializers import SerializerMethodField
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
+from rest_framework.serializers import SerializerMethodField, CharField, IntegerField
+from bluedot_rest_framework import import_string
 
-EventRegister = import_string(api_settings.EVENT['register']['models'])
-Event = import_string(api_settings.EVENT['models'])
+
+Event = import_string('EVENT.models')
+EventRegister = import_string('EVENT.register.models')
 
 
 class EventRegisterSerializer(CustomSerializer):
     event_data = SerializerMethodField()
+    user_id = IntegerField(required=False)
+    unionid = CharField(required=False)
+    openid = CharField(required=False)
+    wechat_id = IntegerField(required=False)
 
     class Meta:
         model = EventRegister
