@@ -1,18 +1,18 @@
 from datetime import datetime
 from rest_framework.serializers import SerializerMethodField
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
+from bluedot_rest_framework import import_string
+
+Event = import_string('EVENT.models')
 
-Event = import_string(api_settings.EVENT['models'])
 
 class EventSerializer(CustomSerializer):
-    time_state=SerializerMethodField()
+    time_state = SerializerMethodField()
+
     class Meta:
         model = Event
         fields = '__all__'
 
-
     def get_time_state(self, queryset):
         date_now = datetime.now()
         time_state = 1
@@ -22,4 +22,4 @@ class EventSerializer(CustomSerializer):
             time_state = 2
         elif queryset.end_time < date_now:
             time_state = 3
-        return time_state
\ No newline at end of file
+        return time_state
