@@ -1,23 +1,18 @@
 from rest_framework.routers import DefaultRouter
-from django.utils.module_loading import import_string
-from bluedot_rest_framework.settings import api_settings
+from bluedot_rest_framework import import_string
 
-EventQuestionView = import_string(api_settings.EVENT['question']['views'])
-EventQuestionUserView = import_string(
-    api_settings.EVENT['question']['user_views'])
-EventScheduleView = import_string(api_settings.EVENT['schedule']['views'])
-EventSpeakerView = import_string(api_settings.EVENT['speaker']['views'])
-EventDataDownloadView = import_string(
-    api_settings.EVENT['data_download']['views'])
-EventRegisterView = import_string(api_settings.EVENT['register']['views'])
-EventChatView = import_string(api_settings.EVENT['chat']['views'])
-EventConfigurationView = import_string(
-    api_settings.EVENT['configuration']['views'])
-EventView = import_string(api_settings.EVENT['views'])
-EventCommentView = import_string(api_settings.EVENT['comment']['views'])
-EventVoteView = import_string(api_settings.EVENT['vote']['views'])
-
-EventVenueView = import_string(api_settings.EVENT['venue']['views'])
+EventView = import_string('EVENT.views')
+EventQuestionView = import_string('EVENT.question.views')
+EventQuestionUserView = import_string('EVENT.question.user_views')
+EventScheduleView = import_string('EVENT.schedule.views')
+EventSpeakerView = import_string('EVENT.speaker.views')
+EventDataDownloadView = import_string('EVENT.data_download.views')
+EventRegisterView = import_string('EVENT.register.views')
+EventChatView = import_string('EVENT.chat.views')
+EventConfigurationView = import_string('EVENT.configuration.views')
+EventCommentView = import_string('EVENT.comment.views')
+EventVoteView = import_string('EVENT.vote.views')
+EventVenueView = import_string('EVENT.venue.views')
 
 
 router = DefaultRouter(trailing_slash=False)
