@@ -15,3 +15,10 @@ def get_tree_menu(data, parent):
         if parent == item['id']:
             state = False
     return state
+
+
+def orm_bulk_update(queryset, update_dict):
+    if queryset and update_dict:
+        for key in update_dict:
+            setattr(queryset, key, update_dict[key])
+        return queryset.save()
