@@ -9,12 +9,13 @@ class CreateQrcode:
             scene=_id, page=page)
         path = f"mi/qrcode/{_id}.jpg"
         OSS().put_object_bytes(res, path)
-        url = f"https://spgchinaratings.oss-cn-beijing.aliyuncs.com/{path}"
+        url = f"https://cpa-global.oss-cn-beijing.aliyuncs.com/{path}"
         return url
 
     def offiaccount_event_live(scene_str):
         res = OfficialAccount.qrcode.create({
-            'action_name': 'QR_LIMIT_STR_SCENE',
+            'expire_seconds': 86400,
+            'action_name': 'QR_STR_SCENE',
             'action_info': {
                 'scene': {'scene_str': scene_str},
             }
@@ -22,5 +23,5 @@ class CreateQrcode:
         res = OfficialAccount.qrcode.get_url(res['ticket'])
         path = f"mi/qrcode/{scene_str}.jpg"
         OSS().put_object_internet(res, path)
-        url = f"https://spgchinaratings.oss-cn-beijing.aliyuncs.com/{path}"
+        url = f"https://cpa-global.oss-cn-beijing.aliyuncs.com/{path}"
         return url
