@@ -1,7 +1,7 @@
 from django.conf.urls import url
 from rest_framework.routers import DefaultRouter
 
-from .qrcode.views import WeChatQrcodeView
+from .qrcode.views import WeChatQrcodeView, WeChatQrcodeLoginView
 # from .template_message import event_register_template
 from .views import JSSdk, OAuth, Token, Menu
 # from .response import Response
@@ -16,6 +16,7 @@ urlpatterns = [
     # url(r'^wechat/template_message/event_register_template',
     #     event_register_template),
     url(r'^wechat/menu', Menu.as_view()),
+    url(r'^wechat/qrcode/login', WeChatQrcodeLoginView.as_view()),
 ]
 
 router = DefaultRouter(trailing_slash=False)
